summaryrefslogtreecommitdiffstats
path: root/src/H5HGquery.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2012-02-09 03:13:27 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2012-02-09 03:13:27 (GMT)
commit9c9ee2008c10801c11bce8563894d9a30ba9a959 (patch)
treec2b89df08fa3895d3fae1a4ad87353f9aabee598 /src/H5HGquery.c
parenteb0e5f8c4ea29e674c97a8be048814e26379d4c1 (diff)
downloadhdf5-9c9ee2008c10801c11bce8563894d9a30ba9a959.zip
hdf5-9c9ee2008c10801c11bce8563894d9a30ba9a959.tar.gz
hdf5-9c9ee2008c10801c11bce8563894d9a30ba9a959.tar.bz2
[svn-r21919] Description:
Refactor function name macros and simplify the FUNC_ENTER macros, to clear away the cruft and prepare for further cleanups. Tested on: Mac OSX/64 10.7.3 (amazon) w/debug, production & parallel
Diffstat (limited to 'src/H5HGquery.c')
-rw-r--r--src/H5HGquery.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5HGquery.c b/src/H5HGquery.c
index ae0a2b7..a1b3777 100644
--- a/src/H5HGquery.c
+++ b/src/H5HGquery.c
@@ -87,8 +87,8 @@
haddr_t
H5HG_get_addr(const H5HG_heap_t *heap)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HG_get_addr)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(heap);
@@ -111,8 +111,8 @@ H5HG_get_addr(const H5HG_heap_t *heap)
size_t
H5HG_get_size(const H5HG_heap_t *heap)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HG_get_size)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(heap);
@@ -135,8 +135,8 @@ H5HG_get_size(const H5HG_heap_t *heap)
size_t
H5HG_get_free_size(const H5HG_heap_t *heap)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HG_get_free_size)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(heap);